#error "/home/espenr/tmp/qt-3.1-espenr-14496/qt/extensions/nsplugin/src/npwin.cpp must be provided by Netscape"
#error "This file is just a placeholder. Please see the documentation"
#error "to learn how to obtain the real file"
